@@ -61,7 +61,7 @@ def get_configure_commands(source: pathlib.Path, destination: pathlib.Path,
 
             if BITNESS == 64:
 
-                filtered_generator_options = [option for option in filtered_generators[0].options if "64".casefold() in option.casefold()]
+                filtered_generator_options = [option for generator in filtered_generators for option in generator.options if "64".casefold() in option.casefold()]
 
                 if len(filtered_generator_options) > 0:
 
@@ -69,10 +69,7 @@ def get_configure_commands(source: pathlib.Path, destination: pathlib.Path,
 
                 else:
 
-                    raise Exception(f"{BITNESS}bit Visual Studio not found, "
-                                    f"but Visual Studio is installed. Make "
-                                    f"sure you have the correct compilers for "
-                                    f"your Python platform ({BITNESS}bit)")
+                    generator_option = filtered_generators[0].options[0]
 
             else:
 
@@ -102,7 +99,9 @@ def get_configure_commands(source: pathlib.Path, destination: pathlib.Path,
 
     if platform.system() == "Linux":
 
-        pass
+        commands.append([os.path.join(str(source.absolute()), 
+                         "build_files", "build_environment", 
+                         "install_deps.sh")])
 
     commands.append(['cmake',
                      '-DWITH_PLAYER=OFF', '-DWITH_PYTHON_INSTALL=OFF',
@@ -112,9 +111,9 @@ def get_configure_commands(source: pathlib.Path, destination: pathlib.Path,
                      "-DWITH_CYCLES_CUDA_BINARIES=ON" if with_cuda else "",
                      "-DWITH_CYCLES_DEVICE_OPTIX=ON" if with_optix else "",
                      f"-DOPTIX_ROOT_DIR={optix_sdk_path}" if 
-                     optix_sdk_path is not None else ""] + os_configure_args, 
-                     '-S' + str(source.absolute()), 
-                     '-B' + str(destination.absolute()))
+                     optix_sdk_path is not None else ""] + os_configure_args + 
+                    ['-S' + str(source.absolute()), 
+                     '-B' + str(destination.absolute())])
 
     return commands
 
